pub struct Coordinate { /* private fields */ }Expand description
A hex coordinate using a cubic coordinate scheme.
See http://www.redblobgames.com/grids/hexagons/#coordinates for more detail.
All three coordinates must sum to zero.
Implementations
Sourceimpl Coordinate
impl Coordinate
Sourcepub fn new() -> Result<Self, &'static str>
pub fn new() -> Result<Self, &'static str>
Create a new Coordinate at 0, 0, 0.
This returns a Result to match at, but always succeeds.
Sourcepub fn at(x: i64, y: i64, z: i64) -> Result<Self, &'static str>
pub fn at(x: i64, y: i64, z: i64) -> Result<Self, &'static str>
Create a new Coordinate at the specified location, if that location is valid.
Sourcepub fn neighbors(&self) -> Vec<Coordinate>
pub fn neighbors(&self) -> Vec<Coordinate>
Get the six neighbors of a given Coordinate.
Sourcepub fn neighbor(&self, direction: usize) -> Result<Coordinate, &'static str>
pub fn neighbor(&self, direction: usize) -> Result<Coordinate, &'static str>
Get the neighbor in direction. Valid directions are in [0, 5].
Sourcepub fn distance_to(&self, other: Coordinate) -> i64
pub fn distance_to(&self, other: Coordinate) -> i64
Get the distance between two coordinates, in grid tiles.